@@ -1,16 +1,20 @@
-# Copyrights 2011-2015 by [Mark Overmeer].
+# Copyrights 2011-2020 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
-use warnings;
-use strict;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution POSIX-1003.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package POSIX::1003::Proc;
 use vars '$VERSION';
-$VERSION = '0.99_07';
+$VERSION = '1.00';
 
 use base 'POSIX::1003::Module';
 
+use warnings;
+use strict;
+
 my @constants;
 my @functions = qw/
  abort
@@ -18,6 +22,7 @@ my @functions = qw/
  WEXITSTATUS WIFEXITED WIFSIGNALED WIFSTOPPED
  WSTOPSIG WTERMSIG 
 
+ getpid getppid
  _exit pause setpgid setsid tcgetpgrp tcsetpgrp
  ctermid cuserid getcwd nice
  /;
@@ -62,6 +67,7 @@ sub setsid()      {goto &POSIX::setsid}
 sub cgetpgrp($)   {goto &POSIX::cgetpgrp}
 sub tcsetpgrp($$) {goto &POSIX::tcsetpgrp}
 
+# getpid and getppid implemented in XS
 
 sub nice($)       {goto &POSIX::nice}
 
